@@ -1,6 +1,7 @@
+#!/usr/bin/env python
 import sys
 
 from .cli import main
 
-if __name__ == "__main__":
+if __name__ == "__main__":  # pragma: no cover
     sys.exit(main(sys.argv[1:]))
